@@ -3,7 +3,6 @@
 #ifndef _MD2_H_
 #define _MD2_H_
 
-#include <sys/cdefs.h>
 #include <sys/types.h>
 
 #include <stdint.h>
@@ -18,7 +17,10 @@ typedef struct MD2Context {
 	unsigned char X[48];		/* input buffer */
 } MD2_CTX;
 
-__BEGIN_DECLS
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void	MD2Init(MD2_CTX *);
 void	MD2Update(MD2_CTX *, const unsigned char *, unsigned int);
 void	MD2Final(unsigned char[16], MD2_CTX *);
@@ -26,6 +28,9 @@ char	*MD2End(MD2_CTX *, char *);
 char	*MD2File(const char *, char *);
 char	*MD2FileChunk(const char *, char *, off_t, off_t);
 char	*MD2Data(const unsigned char *, size_t, char *);
-__END_DECLS
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* _MD2_H_ */
