@@ -95,13 +95,6 @@ static const unsigned char *pad[] = {
  */
 /*static*/ void MD2Transform(MD2_CTX *);
 
-#ifdef __weak_alias
-__weak_alias(MD2Init,_MD2Init)
-__weak_alias(MD2Update,_MD2Update)
-__weak_alias(MD2Final,_MD2Final)
-__weak_alias(MD2Transform,_MD2Transform)
-#endif
-
 void
 MD2Init(MD2_CTX *context)
 {
